#
# spec file for package python-opentelemetry-proto
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-proto
Version:        1.27.0
Release:        1.2
Summary:        OpenTelemetry Python Proto
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-proto/opentelemetry_proto-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module protobuf >= 3.19}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-protobuf >= 3.19
BuildArch:      noarch
%python_subpackages

%description
This library contains the generated code for OpenTelemetry protobuf data model.
The code in the current package was generated using the v0.17.0 release_ of
opentelemetry-proto.

%prep
%autosetup -p1 -n opentelemetry_proto-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%dir %{python_sitelib}/opentelemetry
%{python_sitelib}/opentelemetry/proto
%{python_sitelib}/opentelemetry_proto-%{version}.dist-info

%changelog
* Wed Sep  4 2024 Guang Yee <gyee@suse.com>
- update to 1.27.0:
  * Implementation of Events API
  * Make log sdk add exception.message to logRecord for exceptions whose argument is an exception not a string message
  * Fix use of link.attributes.dropped, which may not exist
  * Running mypy on SDK resources
  * Added py.typed file to top-level module
  * Drop Final annotation from Enum in semantic conventions
  * Update log export example to not use root logger
  * Update semantic conventions to version 1.27.0
  * Add support to type bytes for OTLP AnyValue
  * Export ExponentialHistogram and ExponentialHistogramDataPoint
  * Implement Client Key and Certificate File Support for All OTLP Exporters
  * Remove _start_time_unix_nano attribute from _ViewInstrumentMatch in favor of using time_ns() at the moment when the aggregation object is created
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.25.0:
  * Add OpenTelemetry trove classifiers to PyPI packages
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Make create_gauge non-abstract method
  * Make `tracer.start_as_current_span()` decorator work with
    async functions
  * Fix python 3.12 deprecation warning
  * bump mypy to 0.982
  * Add support for OTEL_SDK_DISABLED environment variable
  * Fix ValueError message for PeriodicExportingMetricsReader
  * Use `BaseException` instead of `Exception` in
    `record_exception`
  * Make span.record_exception more robust
  * Fix license field in pyproject.toml files
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.23.0:
  * drop python 3.7 support
  * update to opentelemetry 0.20.0 data model, which includes:
    + Handle HTTP 2XX responses as successful in OTLP exporters
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- Initial package (1.22.0)
